==> Aurora_OS-4.0.1.43-base-Aurora_SDK_Target-i486.tar.7z: usr/include/libsailfishmdm/mdm-devicelocksettings.h <==
/*
 * Copyright (c) 2021 Open Mobile Platform LLC.
 *
 * License: Proprietary
 */

#ifndef SAILFISH_MDM_DEVICELOCKSETTINGS_H
#define SAILFISH_MDM_DEVICELOCkSETTINGS_H

#include <QString>
#include <QDBusVariant>
#include <QDBusInterface>
#include <QObject>
#include <QSharedPointer>

#include "mdm-devicelock.h"

namespace Sailfish {
namespace Mdm {

class Q_DECL_EXPORT DeviceLockSettings : public QObject
{
    Q_OBJECT

public:

    explicit DeviceLockSettings(QObject *parent = nullptr);

    static QList<Qt::DayOfWeek> fromStringScheduleDays(const QString &schedDays);
    static QPair<QTime, QTime> fromStringScheduleTime(const QString &schedTime);

    bool setPasswordStrength(bool strength);
    bool getPasswordStrength();

    Sailfish::Mdm::DeviceLock::Result setPasswordLength(uint length);
    uint getPasswordLength();

    bool setPasswordMaxAge(uint days);
    uint getPasswordMaxAge();

    bool setPasswordWarningPeriod(uint days);
    uint getPasswordWarningPeriod();

    Sailfish::Mdm::DeviceLock::Result setLoginTimeToLive(uint uid, QDate ttl);
    QDate getLoginTimeToLive(uint uid);

    Sailfish::Mdm::DeviceLock::Result setScheduleDays(uint uid, const QList<Qt::DayOfWeek> &schedDays);
    QList<Qt::DayOfWeek> getScheduleDays(uint uid);

    Sailfish::Mdm::DeviceLock::Result setScheduleTime(uint uid, const QPair<QTime, QTime> &schedTime);
    QPair<QTime, QTime> getScheduleTime(uint uid);

private:
    QDBusInterface m_iface;
    Q_DISABLE_COPY(DeviceLockSettings)
};
} // namespace Mdm
} // namespace Sailfish

#endif // SAILFISH_MDM_DEVICELOCKSETTINGS_H

==> Aurora_OS-4.0.2.284-base-Aurora_SDK_Target-i486.tar.7z: usr/include/libsailfishmdm/mdm-devicelocksettings.h <==
/*
 * Copyright (c) 2021 Open Mobile Platform LLC.
 *
 * License: Proprietary
 */

#ifndef SAILFISH_MDM_DEVICELOCKSETTINGS_H
#define SAILFISH_MDM_DEVICELOCkSETTINGS_H

#include <QString>
#include <QDBusVariant>
#include <QDBusInterface>
#include <QObject>
#include <QSharedPointer>

#include "mdm-devicelock.h"

namespace Sailfish {
namespace Mdm {

class Q_DECL_EXPORT DeviceLockSettings : public QObject
{
    Q_OBJECT

public:

    explicit DeviceLockSettings(QObject *parent = nullptr);

    static QList<Qt::DayOfWeek> fromStringScheduleDays(const QString &schedDays);
    static QPair<QTime, QTime> fromStringScheduleTime(const QString &schedTime);

    bool setPasswordStrength(bool strength);
    bool getPasswordStrength();

    Sailfish::Mdm::DeviceLock::Result setPasswordLength(uint length);
    uint getPasswordLength();

    bool setPasswordMaxAge(uint days);
    uint getPasswordMaxAge();

    bool setPasswordWarningPeriod(uint days);
    uint getPasswordWarningPeriod();

    Sailfish::Mdm::DeviceLock::Result setLoginTimeToLive(uint uid, QDate ttl);
    QDate getLoginTimeToLive(uint uid);

    Sailfish::Mdm::DeviceLock::Result setScheduleDays(uint uid, const QList<Qt::DayOfWeek> &schedDays);
    QList<Qt::DayOfWeek> getScheduleDays(uint uid);

    Sailfish::Mdm::DeviceLock::Result setScheduleTime(uint uid, const QPair<QTime, QTime> &schedTime);
    QPair<QTime, QTime> getScheduleTime(uint uid);

    Sailfish::Mdm::DeviceLock::Result setLoginLocked(uint uid, bool value);
    bool getLoginLocked(uint uid);

private:
    QDBusInterface m_iface;
    Q_DISABLE_COPY(DeviceLockSettings)
};
} // namespace Mdm
} // namespace Sailfish

#endif // SAILFISH_MDM_DEVICELOCKSETTINGS_H
